import json
import os
import sys

from rtgmpy import BuildingCodeRTGMCalc


cur_dir = os.path.dirname(os.path.realpath(__file__))
src_dir = os.path.abspath(os.path.join(cur_dir, ".."))
sys.path.append(src_dir)


# Function for running
def run_rtgm(csv_path, code_string, out_path=None):
    # Initialize with default (random) site data
    rtgm_calc = BuildingCodeRTGMCalc()
    # Run with csv input and building code string
    rtgm_data = rtgm_calc.calc_rtgm(haz_data=csv_path, bldg_code=code_string)

    if out_path:
        # Output data
        fname = os.path.basename(out_path).split(".json")[0]
        # If the parent directory exists...
        out_dir = os.path.dirname(out_path)
        if os.path.isdir(out_dir):
            out_files = [file for file in os.listdir(out_dir) if ".json" in file]
            # If there isn't a conflict, go ahead and create the original name
            if fname + ".json" not in out_files:
                out_name = out_path
            # Otherwise we append integers until a unique filename is found
            else:
                suff = 1
                out_test = "%s-%d.json" % (fname, suff)
                while out_test in out_files:
                    suff += 1
                    out_test = "%s-%d.json" % (fname, suff)
                out_name = os.path.join(out_dir, out_test)
        # If the parent directory doesn't exist...
        else:
            new_dir = os.path.dirname(out_path)
            os.mkdir(new_dir)
            out_name = out_path

        # Dump the dictionary results
        with open(out_name, "w") as f:
            json.dump(rtgm_data, f)

    return rtgm_data


# Extracting input params from system arguments
args = sys.argv
code_string = args[1]
csv_path = args[2]

# Try extracting output path (if provided)
try:
    out_path = args[3]
except (IndexError):
    out_path = os.path.join(src_dir, "json-output", "output.json")

if __name__ == "__main__":
    if out_path == "no-output":
        data = run_rtgm(csv_path, code_string, out_path=None)
    else:
        data = run_rtgm(csv_path, code_string, out_path)
